Learn R Programming

bayesSSM (version 0.7.1)

.compute_log_jacobian: Internal function to compute the Jacobian of the transformation

Description

Internal function to compute the Jacobian of the transformation

Usage

.compute_log_jacobian(theta, transform)

Value

log-Jacobian of the transformation

Arguments

theta

parameter vector (on original scale)

transform

transformation type for each parameter