Learn R Programming

bayesSSM (version 0.7.1)

particle_filter: Particle filter functions

Description

The package provides several particle filter implementations for state-space models for estimating the intractable marginal likelihood \(p(y_{1:T}\mid \theta)\):

  • auxiliary_filter

  • bootstrap_filter

  • resample_move_filter

The simplest one is the bootstrap_filter, and is thus recommended as a starting point.

Arguments